@@ -23,6 +23,14 @@
 ####################### HERE FOLLOW CONFIGURATION DATA #####################
 ####### TAKE CARE: JUST PARTS _IN RED_ SOULD TO BE SAFELY EDITABLE! ########
 
+@varn = ( [ [1, 2, 3] ] ); # VARIABLE NUMBERS. THE PROGRAM TRIPLES THE SERIES: IT TRANSFORMS IT IN 1, 2, 3, 1, 2, 3, 1, 2, 3.
+@midvalues = (2, 2, 2); # POINT TO POINT CORRENSPODENCE WITH THE ABOVE. THE MID ITERATION NUMBER FOR EACH PARAMETER.
+# I.E. THREE ITERATION PER PARAMETER, VALUE "2" FOR EACH $midvalue (@midvalues). 
+
+@casegroup = ( [ [3, 2], [4, 2] ] ) ; # BETWEEN SQUARE BRACKETS ARE THE BLOCKS OF BLOCK COORDINATE SEARCH. THE FIRST ITEM IN 
+# EACH SQUARE BRACKET IS THE POSITION OF THE FIRST ITEM IN THE ACTIVE BLOCK (INDEX FROM 0). THE SECOND ITEM IS THE DIMENSION OF THE ACTIVE BLOCK,
+# IN TERMS OF NUMBER OF PARAMETERS.
+
 $file = 
 "ame";  
 # Write here the root model directory.
